==> fishsupper-0.1.3.tar.gz: fishsupper-0.1.3/src/bonus.h <==
//  Fish Supper
//  Copyright (C) 2006 Matthew Clarke <matthew_larcke@lycos.co.uk>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
//  02111-1307, USA.




#ifndef _BONUS_H_
#define _BONUS_H_




#include "collectablesprite.h"
#include "constants.h"
#include "enums.h"
#include "playdisplay.h"




namespace FS
{
    
class Bonus : public CollectableSprite
{
    private:
            
        BonusType my_bonus_type;
        int points; // this is only used for TREATs
    
        bool update_visible;
        
    public:
            
        Bonus(int _y, int _width, int _height, int _map_x, int _row,
                int _row_length_pixels, Direction _direction, BonusType _bonus_type);
        
        ~Bonus();
        
        void update(const int * current_start_pixels, const int * pixels_to_move,
                const int * old_pixels_to_move, bool is_first_pass, PlayDisplay * pd);
        
        void reset() { active = true; }
        
        BonusType get_bonus_type() const { return my_bonus_type; }
        
}; // class Bonus

} // namespace FS




#endif

==> fishsupper-0.1.4.tar.gz: fishsupper-0.1.4/src/bonus.h <==
// $Id: bonus.h,v 1.4 2006/08/05 09:08:58 matthew Exp $

//  Fish Supper
//  Copyright (C) 2006 Matthew Clarke <matthew_larcke@lycos.co.uk>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
//  02111-1307, USA.




#ifndef _BONUS_H_
#define _BONUS_H_




#include "collectablesprite.h"
#include "constants.h"
#include "enums.h"
#include "playdisplay.h"




namespace FS
{
    
class Bonus : public CollectableSprite
{
    private:

        static const int COLL_BOX_X_OFFSET = 17;
        static const int COLL_BOX_Y_OFFSET = 21;
        static const int COLL_BOX_WIDTH = 10;
        static const int COLL_BOX_HEIGHT = 9;
                    
        BonusType my_bonus_type;
        int points; // this is only used for TREATs
    
        bool update_visible;
        
    public:
            
        Bonus(int _y, int _width, int _height, int _map_x, int _row,
                int _row_length_pixels, BonusType _bonus_type);
        
        ~Bonus();
        
        void update(const int * current_start_pixels, const int * pixels_to_move,
                const int * old_pixels_to_move, const Direction * directions,
                bool is_first_pass, PlayDisplay * pd);
        
        void reset() { active = true; }
        
        BonusType get_bonus_type() const { return my_bonus_type; }
        
}; // class Bonus

} // namespace FS




#endif
